@@ -48,6 +48,7 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.LinkedHashMap;
 import java.util.List;
+import java.util.Locale;
 import java.util.Map;
 import java.util.MissingResourceException;
 import java.util.Properties;
@@ -187,9 +188,14 @@ public class ConfigurationImpl
 
         // let system properties override other globals
         try {
-            fromProperties(new HashMap(
-                AccessController.doPrivileged(
-                    J2DoPrivHelper.getPropertiesAction())));
+            Properties systemProperties = AccessController.doPrivileged(
+                    J2DoPrivHelper.getPropertiesAction());
+            HashMap sysPropHM = null;
+            synchronized(systemProperties) {
+                // Prevent concurrent modification of systemProperties until HashMap ctor is completed.
+                sysPropHM = new HashMap(systemProperties);
+            }
+            fromProperties(sysPropHM);
         } catch (SecurityException se) {
             // security manager might disallow
         }
@@ -839,7 +845,7 @@ public class ConfigurationImpl
         // specific implementation of OpenJPA
         String[] prefixes = ProductDerivations.getConfigurationPrefixes();
         for (String prefix : prefixes) {
-            if (propName.toLowerCase().startsWith(prefix)
+            if (propName.toLowerCase(Locale.ENGLISH).startsWith(prefix)
                 && propName.length() > prefix.length() + 1
                 && propName.indexOf('.', prefix.length()) == prefix.length()
                 && propName.indexOf('.', prefix.length() + 1) == -1
